@@ -29,9 +29,9 @@ hemilist <- function(lh_data = NULL, rh_data = NULL) {
 #'
 #' @param hemi character string, one of 'lh' or 'rh'. The name to use for the data in the returned list.
 #'
-#' @param hemilist optional hemilist, an existing hemilist to add the entry to. If left at the default value `NULL`, a new list will be created.
+#' @param hemilist optional \code{\link{hemilist}}, an existing hemilist to add the entry to. If left at the default value `NULL`, a new list will be created.
 #'
-#' @return named list, with the 'data' in the name given by parameter 'hemi'
+#' @return a \code{\link{hemilist}}: a named list, with the 'data' in the name given by parameter 'hemi'
 #'
 #' @family hemilist functions
 #'
@@ -60,6 +60,8 @@ hemilist.wrap <- function(data, hemi, hemilist=NULL) {
 #'
 #' @family hemilist functions
 #'
+#' @note See \code{\link{hemilist}} for details.
+#'
 #' @export
 hemilist.derive.hemi <- function(hemilist) {
     if(!is.hemilist(hemilist)) {
@@ -80,7 +82,7 @@ hemilist.derive.hemi <- function(hemilist) {
 
 #' @title Unwrap hemi data from a named hemi list.
 #'
-#' @param hemi_list named list, can have entries 'lh' and/or 'rh'
+#' @param hemi_list named list, can have entries 'lh' and/or 'rh', see \code{\link{hemilist}}.
 #'
 #' @param hemi character string, the hemi data name to retrieve from the list. Can be NULL if the list only has a single entry.
 #'
@@ -127,7 +129,7 @@ hemilist.unwrap <- function(hemi_list, hemi=NULL, allow_null_list=FALSE) {
 
 #' @title Get combined data of hemi list
 #'
-#' @param hemi_list named list, can have entries 'lh' and/or 'rh'
+#' @param hemi_list named list, can have entries 'lh' and/or 'rh', see \code{\link{hemilist}}
 #'
 #' @return the data combined with \code{\link{c}}, or NULL if both entries are NULL.
 #'
@@ -151,7 +153,7 @@ hemilist.get.combined.data <- function(hemi_list) {
 
 #' @title Check whether x is a hemilist
 #'
-#' @description A hemilist is a named list with entries 'lh' and/or 'rh'.
+#' @description A hemilist is a named list with entries 'lh' and/or 'rh', see \code{\link{hemilist}}.
 #'
 #' @param x any R object
 #'
@@ -163,3 +165,43 @@ hemilist.get.combined.data <- function(hemi_list) {
 is.hemilist <- function(x) {
     return(is.list(x) & ("lh" %in% names(x) | "rh" %in% names(x)));
 }
+
+
+#' @title Create a hemilist from a named list with keys prefixed with 'lh_' and 'rh_'.
+#'
+#' @description A hemilist is a named list with entries 'lh' and/or 'rh', see \code{\link{hemilist}}.
+#'
+#' @param named_list a named list, the keys must start with 'lh_' or 'rh_' to be assigned to the 'lh' and 'rh' entries of the returned hemilist. Other entries will be ignored.
+#'
+#' @param report_ignored logical, whether to print a message with the ignored entries, if any.
+#'
+#' @param return_ignored logical, whether to add a key 'ignored' to the returned hemilist, containing the ignored entries.
+#'
+#' @return a hemilist
+#'
+#' @family hemilist functions
+#'
+#' @export
+hemilist.from.prefixed.list <- function(named_list,  report_ignored=TRUE, return_ignored=FALSE) {
+    lh_list = list();
+    rh_list = list();
+    ignored = list();
+    for(entry in names(named_list)) {
+        if(startsWith(entry, 'lh_')) {
+            lh_list[[substring(entry, 4L)]] = named_list[[entry]];
+        } else if(startsWith(entry, 'rh_')) {
+            rh_list[[substring(entry, 4L)]] = named_list[[entry]];
+        } else {
+            ignored[[entry]] = named_list[[entry]];
+        }
+    }
+    if(report_ignored) {
+        message(sprintf("Ignoring %d entries that do not start with 'lh_' or 'rh_': ''.\n", length(ignored), paste(ignored, sep=", ")));
+    }
+    res = list('lh'=lh_list, 'rh'=rh_list);
+    if(return_ignored) {
+        res$ignored = ignored;
+    }
+    return(res);
+}
+
